@@ -33,8 +33,7 @@ CONTAINER_GET = 'container:get'
 
 def container_not_found():
     """Throw exception indicating container not found."""
-    pecan.abort(404, u._('Not Found. Sorry but your container is in '
-                         'another castle.'))
+    pecan.abort(404, u._('Secrets container not found.'))
 
 
 def invalid_container_id():
@@ -46,21 +45,16 @@ class ContainerController(controllers.ACLMixin):
     """Handles Container entity retrieval and deletion requests."""
 
     def __init__(self, container):
+        super().__init__()
         self.container = container
         self.container_id = container.id
         self.consumer_repo = repo.get_container_consumer_repository()
         self.container_repo = repo.get_container_repository()
         self.validator = validators.ContainerValidator()
         self.consumers = consumers.ContainerConsumersController(
-            self.container_id)
+            self.container)
         self.acl = acls.ContainerACLsController(self.container)
 
-    def get_acl_tuple(self, req, **kwargs):
-        d = self.get_acl_dict_for_user(req, self.container.container_acls)
-        d['project_id'] = self.container.project.external_id
-        d['creator_id'] = self.container.creator_id
-        return 'container', d
-
     @pecan.expose(generic=True, template='json')
     def index(self, **kwargs):
         pecan.abort(405)  # HTTP 405 Method Not Allowed as default
@@ -113,6 +107,7 @@ class ContainersController(controllers.ACLMixin):
     """Handles Container creation requests."""
 
     def __init__(self):
+        super().__init__()
         self.consumer_repo = repo.get_container_consumer_repository()
         self.container_repo = repo.get_container_repository()
         self.secret_repo = repo.get_secret_repository()
@@ -149,6 +144,7 @@ class ContainersController(controllers.ACLMixin):
             offset_arg=kw.get('offset', 0),
             limit_arg=kw.get('limit', None),
             name_arg=kw.get('name', None),
+            type_arg=kw.get('type', None),
             suppress_exception=True
         )
 
@@ -230,6 +226,7 @@ class ContainersSecretsController(controllers.ACLMixin):
 
     def __init__(self, container):
         LOG.debug('=== Creating ContainerSecretsController ===')
+        super().__init__()
         self.container = container
         self.container_secret_repo = repo.get_container_secret_repository()
         self.secret_repo = repo.get_secret_repository()
