@@ -12,12 +12,14 @@
 
 from oslo_policy import policy
 
+_READER = "role:reader"
+_SYSTEM_ADMIN = "role:admin and system_scope:all"
 
 rules = [
     policy.DocumentedRuleDefault(
         name='transport_key:get',
-        check_str='rule:all_users',
-        scope_types=[],
+        check_str=f'rule:all_users or {_READER}',
+        scope_types=['project', 'system'],
         description='Get a specific transport key.',
         operations=[
             {
@@ -28,8 +30,8 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='transport_key:delete',
-        check_str='rule:admin',
-        scope_types=[],
+        check_str=f'{_SYSTEM_ADMIN}',
+        scope_types=['system'],
         description='Delete a specific transport key.',
         operations=[
             {
@@ -40,8 +42,8 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='transport_keys:get',
-        check_str='rule:all_users',
-        scope_types=[],
+        check_str=f'rule:all_users or {_READER}',
+        scope_types=['project', 'system'],
         description='Get a list of all transport keys.',
         operations=[
             {
@@ -52,8 +54,8 @@ rules = [
     ),
     policy.DocumentedRuleDefault(
         name='transport_keys:post',
-        check_str='rule:admin',
-        scope_types=[],
+        check_str=f'{_SYSTEM_ADMIN}',
+        scope_types=['system'],
         description='Create a new transport key.',
         operations=[
             {
