@@ -15,7 +15,6 @@
 Default implementation of Barbican certificate processing plugins and support.
 """
 from barbican.common import utils
-from barbican import i18n as u
 from barbican.plugin.interface import certificate_manager as cert
 
 LOG = utils.getLogger(__name__)
@@ -51,7 +50,7 @@ class SimpleCertificatePlugin(cert.CertificatePluginBase):
                   populated by the plugin implementation
         :rtype: :class:`ResultDTO`
         """
-        LOG.info(u._LI('Invoking issue_certificate_request()'))
+        LOG.info('Invoking issue_certificate_request()')
         return cert.ResultDTO(
             cert.CertificateStatus.WAITING_FOR_CA,
             retry_msec=MSEC_UNTIL_CHECK_STATUS)
@@ -71,7 +70,7 @@ class SimpleCertificatePlugin(cert.CertificatePluginBase):
                   populated by the plugin implementation
         :rtype: :class:`ResultDTO`
         """
-        LOG.info(u._LI('Invoking modify_certificate_request()'))
+        LOG.info('Invoking modify_certificate_request()')
         return cert.ResultDTO(cert.CertificateStatus.WAITING_FOR_CA)
 
     def cancel_certificate_request(self, order_id, order_meta, plugin_meta,
@@ -89,7 +88,7 @@ class SimpleCertificatePlugin(cert.CertificatePluginBase):
                   populated by the plugin implementation
         :rtype: :class:`ResultDTO`
         """
-        LOG.info(u._LI('Invoking cancel_certificate_request()'))
+        LOG.info('Invoking cancel_certificate_request()')
         return cert.ResultDTO(cert.CertificateStatus.REQUEST_CANCELED)
 
     def check_certificate_status(self, order_id, order_meta, plugin_meta,
@@ -107,7 +106,7 @@ class SimpleCertificatePlugin(cert.CertificatePluginBase):
                   populated by the plugin implementation
         :rtype: :class:`ResultDTO`
         """
-        LOG.info(u._LI('Invoking check_certificate_status()'))
+        LOG.info('Invoking check_certificate_status()')
         return cert.ResultDTO(cert.CertificateStatus.CERTIFICATE_GENERATED)
 
     def supports(self, certificate_spec):
@@ -145,7 +144,7 @@ class SimpleCertificateEventPlugin(cert.CertificateEventPluginBase):
                the certificate
         :returns: None
         """
-        LOG.info(u._LI('Invoking notify_certificate_is_ready()'))
+        LOG.info('Invoking notify_certificate_is_ready()')
 
     def notify_ca_is_unavailable(
             self, project_id, order_ref, error_msg, retry_in_msec):
@@ -158,4 +157,4 @@ class SimpleCertificateEventPlugin(cert.CertificateEventPluginBase):
                If this is 0, then no attempt will be made.
         :returns: None
         """
-        LOG.info(u._LI('Invoking notify_ca_is_unavailable()'))
+        LOG.info('Invoking notify_ca_is_unavailable()')
