@@ -14,8 +14,8 @@
 # limitations under the License.
 import base64
 import os
+from unittest import mock
 
-import mock
 from oslo_utils import timeutils
 
 from barbican.api.controllers import secrets
@@ -372,8 +372,18 @@ class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
         self.assertEqual(decoded, get_resp.body)
 
     def test_returns_404_on_get_when_not_found(self):
+        """Test with valid uuid which is not present in DB."""
         get_resp = self.app.get(
-            '/secrets/98c876d9-aaac-44e4-8ea8-441932962b05',
+            '/secrets/{0}'.format(utils.generate_test_valid_uuid()),
+            headers={'Accept': 'application/json'},
+            expect_errors=True
+        )
+        self.assertEqual(404, get_resp.status_int)
+
+    def test_returns_404_on_get_invalid_secret_id(self):
+        """Test where uuid provided is not valid."""
+        get_resp = self.app.get(
+            '/secrets/98c876d9-aaac-44e4-8ea8-invalid-id',
             headers={'Accept': 'application/json'},
             expect_errors=True
         )
@@ -618,7 +628,7 @@ class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
 
         self.assertEqual(201, resp.status_int)
 
-        text_too_big = 'x' * 10050
+        text_too_big = 'x' * 20050
         put_resp = self.app.put(
             '/secrets/{0}'.format(secret_uuid),
             text_too_big,
