@@ -11,8 +11,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
 import threading
+from unittest import mock
 
 from barbican.common import utils as common_utils
 from barbican.plugin.crypto import base
@@ -53,8 +53,7 @@ class WhenTestingManager(utils.BaseTestCase):
         cm.CONF.set_override(
             "enabled_crypto_plugins",
             ['foo_plugin'],
-            group='crypto',
-            enforce_type=True)
+            group='crypto')
 
         manager_to_test = cm.get_manager()
 
