@@ -49,19 +49,18 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-project = u'Barbican'
-copyright = u'2014, OpenStack Foundation'
-repository_name = 'openstack/barbican'
-bug_project = 'barbican'
-bug_tag = ''
+project = 'Barbican'
+copyright = '2014, OpenStack Foundation'
+openstackdocs_repo_name = 'openstack/barbican'
+openstackdocs_pdf_link = True
+openstackdocs_auto_name = False
+openstackdocs_bug_project = 'barbican'
+openstackdocs_bug_tag = ''
 
 # Add any paths that contain "extra" files, such as .htaccess or
 # robots.txt.
 html_extra_path = ['_extra']
 
-# Must set this variable to include year, month, day, hours, and minutes.
-html_last_updated_fmt = '%Y-%m-%d %H:%M'
-
 # If true, '()' will be appended to :func: etc. cross-reference text.
 add_function_parentheses = True
 
@@ -70,7 +69,7 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # -- Options for HTML output --------------------------------------------------
 
@@ -91,8 +90,8 @@ htmlhelp_basename = '%sdoc' % project
 latex_documents = [
     ('index',
      'doc-barbican.tex',
-     u'%s Documentation' % project,
-     u'OpenStack Foundation', 'manual'),
+     '%s Documentation' % project,
+     'OpenStack Foundation', 'manual'),
 ]
 
 latex_use_xindy = False
